@@ -13,6 +13,10 @@ Wed May  8 1991
 
 /* base.c - handle movement, etc. of the base. */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include "vaders.h"
 
 extern int paused;
@@ -48,10 +52,12 @@ XImage *explosion;
 
 int ReadBaseImage()
 {
+/*
   unsigned int width, height;
   int x_hot, y_hot;
   char *data, filename[255];
   int status;
+*/
 
   base->width = (scale == 1) ? base1_width : base2_width;
   base->height = (scale == 1) ? base1_height : base2_height;
@@ -91,30 +97,27 @@ void InitBase()
     }
     basedestroyed = TRUE;
     showingexplosion = FALSE;
-    basetimerid = NULL;
+    basetimerid = 0;
     base->v = 0;
 }
 
 
 
-void PaintBase(gc)
-GC gc;
+void PaintBase(GC gc)
 {
   XPutImage(dpy, gamewindow, gc, base->shape_image,
 	    0, 0, base->x, gameheight-base->height, base->width, base->height);
 }
 
 
-ShowBase(i, gc)
-int i;
-GC gc;
+void ShowBase(int i, GC gc)
 {
   XPutImage(dpy, labelwindow, gc, base->shape_image,
 	    0, 0, i*(base->width+2), gameheight/2-(3*base->height),
 	    base->width, base->height);
 }
 
-PaintBasesLeft()
+void PaintBasesLeft()
 {
   int i;
   XDrawString(dpy, labelwindow, scoregc,
@@ -156,7 +159,7 @@ int x,y;
   return FALSE;
 }
 
-ResetGame()
+void ResetGame()
 {
   static Arg args[1];
 
@@ -182,7 +185,7 @@ ResetGame()
   base->x = base->v = 0;
   showingexplosion = FALSE;
   PaintBase(basegc);
-  XtSetArg(args[0], XtNlabel, "Start");
+  XtSetArg(args[0], XtNlabel, _(" Start"));
   XtSetValues(pausebutton, args, 1);
 }
 
@@ -301,9 +304,9 @@ int x,y;
       r = (y-(gameheight-scale*45))/HUNKHEIGHT;
       c = (x-building->x)/HUNKWIDTH;
       if (r<0 || r>=HUNKROWS)
-	printf("Error in row");
+	printf(_("Error in row"));
       if (c<0 || c>=NUMHUNKS)
-	printf("Error in column");
+	printf(_("Error in column"));
       if(building->hunks[r][c]) {
 	ToastHunk(building, r,c);
 	return TRUE;
@@ -314,7 +317,7 @@ int x,y;
   return FALSE;
 }
 
-InitBuildings()
+void InitBuildings()
 {
   int i, j, k;
 
