@@ -13,6 +13,10 @@ Wed May  8 1991
 
 /* main.c -- create our windows and initialize things. */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #define MAIN
 #include "vaders.h"
 #include <X11/Xaw/Form.h>
@@ -28,6 +32,8 @@ static int width, height;		/* Size of window. */
 static void AddPathToSearchPath();
 #endif
 
+#include <locale.h>
+
 static XrmOptionDescRec table[] = {
     {"-debug",	"*debug",	XrmoptionNoArg,	NULL},
 };
@@ -135,14 +141,15 @@ caddr_t data;
   return w;
 }
 
-main(argc, argv)
-Cardinal argc;
-char **argv;
+int main(Cardinal argc, char **argv)
 {
   static Arg args[10];
   int n;
   Widget form, button;
-  extern WidgetClass labelwidgetclass;
+  /* extern WidgetClass labelwidgetclass; */
+
+  setlocale(LC_ALL, "");
+  textdomain(PACKAGE);
 
   me_image = NULL;
 
@@ -187,6 +194,8 @@ char **argv;
   
   gamewidget = (VadersWidget)
     XtCreateManagedWidget("field", vadersWidgetClass, form, args, n);
+  
+  XtSetKeyboardFocus (form, (Widget) gamewidget);
 
   n = 0;
   XtSetArg (args[n], XtNleft, XtChainLeft); n++;
@@ -202,19 +211,19 @@ char **argv;
     XtCreateManagedWidget("label", vadersWidgetClass, form, args, n);
 
   pausebutton = MakeCommandButton(form, "pause", Pause, labelwidget, gamewidget, NULL);
-  XtSetArg(args[0], XtNlabel, " Start");
+  XtSetArg(args[0], XtNlabel,_(" Start"));
   XtSetArg(args[1], XtNforeground, defaultfore);
   XtSetArg(args[2], XtNbackground, defaultback);
   XtSetArg(args[3], XtNborderColor, defaultfore);
   XtSetValues(pausebutton, args, 4);
   button = MakeCommandButton(form, "quit", Quit, pausebutton, gamewidget, NULL);
-  XtSetArg(args[0], XtNlabel, " Quit ");
+  XtSetArg(args[0], XtNlabel,_(" Quit "));
   XtSetArg(args[1], XtNforeground, defaultfore);
   XtSetArg(args[2], XtNbackground, defaultback);
   XtSetArg(args[3], XtNborderColor, defaultfore);
   XtSetValues(button, args, 4);
   infobutton = MakeCommandButton(form, "info", ShowInfo, button, gamewidget, NULL);
-  XtSetArg(args[0], XtNlabel, " Info ");
+  XtSetArg(args[0], XtNlabel,_(" Info "));
   XtSetArg(args[1], XtNforeground, defaultfore);
   XtSetArg(args[2], XtNbackground, defaultback);
   XtSetArg(args[3], XtNborderColor, defaultfore);
@@ -223,6 +232,7 @@ char **argv;
   XtRealizeWidget(toplevel);
   ResetGame();
   XtMainLoop();
+  return 0;
 }
 
 #ifdef XFILESEARCHPATH
