@@ -15,7 +15,7 @@ Wed May  8 1991
 /* patchlevel.h -- patchlevel for xinvaders */
 
 #define VERSION 2
-#define PATCHLEVEL 0
+#define PATCHLEVEL 1
 
 /* 
 
@@ -48,4 +48,11 @@ Wed May  8 1991
   The application can now run without any customization of resources,
    or knowledge of the file system.
 
+  version 2.1 (by Nicols Lichtmaier <nick@debian.org>):
+  Added i18n support and Spanish translation.
+  Added high score saving.
+  Added automake/autoconf support.
+  The program ignored keypresses if the mouse wasn't over the window.
+  Added Debian packaging files.
+
 */
