@@ -17,6 +17,7 @@ Wed May  8 1991
 #define _vaders_h
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <math.h>
 #include <X11/Xlib.h>
 #include <X11/Xos.h>
@@ -29,6 +30,8 @@ Wed May  8 1991
 
 #include <X11/Xaw/Command.h>
 
+#include <libintl.h>
+
 #ifndef XtRFloat
 #define XtRFloat "Float"
 #endif
@@ -130,8 +133,8 @@ ext int vaderwait;		/* Number of milleseconds to wait between */
 
 ext Pixel spacerpixel;
 ext XtIntervalId spacertimerid;
-ext int spacerwait;		/* Number of milliseconds to wait between
-				/* moving spacers. /*
+ext int spacerwait;		/* Number of milliseconds to wait between */
+				/* moving spacers. */
 ext int spacerappear;		/* same, but for the interval between appearances */
 
 ext Boolean spacer_shown;    	/* Currnet_Spacer is something */
@@ -156,9 +159,8 @@ ext int numvshots;		/* how many shots (from vaders) there are right now. */
 
 ext Pixel scorepixel;
 
-
-ext int bases, nextbonus, hiscore, lastscore;
-
+ext int bases, nextbonus, lastscore;
+extern int hiscore;
 
 ext GC
   foregc, backgc, basegc, buildinggc, vadergc[3],
@@ -168,53 +170,63 @@ ext XImage *me_image;
 
 /* From widget.c */
 
-extern Boolean TakeFocus();
-extern void Quit();
-extern void Pause();
+void Quit();
+void Pause();
 extern int paused;
-extern void SuspendTimers();
-extern void EnableTimers();
-extern void ShowInfo();
+void SuspendTimers();
+void EnableTimers();
+void ShowInfo();
 
 /* From base.c */
 
-extern void MoveBase();
-extern void MoveLeft();
-extern void MoveRight();
-extern void Stop();
-extern void Fire();
-extern Boolean ShotHitsBase();
-extern Boolean ShotHitsBuilding();
-extern void InitBase();
-extern void PaintBase();
-extern void DrawBuildings();
+void MoveBase();
+void MoveLeft();
+void MoveRight();
+void Stop();
+void Fire();
+Boolean ShotHitsBase();
+Boolean ShotHitsBuilding();
+void InitBase();
+void InitBuildings();
+void PaintBase();
+void PaintBasesLeft();
+void DrawBuildings();
+void ResetGame();
+void ShowBase(int i, GC gc);
 
 /* From vaders.c */
 
-extern Boolean ShotHitsVader();
-extern void MoveVaders();
-extern void InitVaders();
-extern void AddVShot();
-extern void MoveVShots();
-extern void CreateVaders();
-extern void PaintAllVaders();
+Boolean ShotHitsVader();
+void MoveVaders();
+void InitVaders();
+void AddVShot();
+void MoveVShots();
+void CreateVaders();
+void PaintAllVaders();
+
+/* from score.c */
+
+void InitScore();
+void PaintScore();
+void SaveScore();
 
 /* from spacer.c */
 
-extern Boolean ShotHitsSpacer();
-extern void MoveSpacer();
-extern void MakeSpacer();
-extern void InitSpacers();
-extern void PaintSpacer();
+Boolean ShotHitsSpacer();
+void MoveSpacer();
+void MakeSpacer();
+void InitSpacers();
+void PaintSpacer();
 
 /* From shot.c */
 
-extern void AddLine();
-extern void AddShot();
-extern void AddVshot();
-extern void MoveShots();
-extern void MoveVshots();
-extern void PaintAllShots();
+void AddLine();
+void AddShot();
+void AddVshot();
+void InitShot();
+void MoveShots();
+void MoveVshots();
+void PaintAllShots();
 ext Pixel defaultfore, defaultback;
 
 ext char *vaderfont;
